# Changelog

1.1.0
-----

* Highlight GPIO label if `--find` matches a hidden label
* Add regex support to `--find`
* Rewrite render flow to make it less hacky
* Light mode is back! `--light`
* Move error text above usage message

1.0.1
-----

* Tidy up readme

1.0.0
-----

* Initial Release
* Ported from https://gist.github.com/Gadgetoid/192af85a3eb05d4a6ac1db076c4ef118
